# [datamine](https://datamine.purdue.edu/)

**datamine** is the complementary package to Purdue University's integrative data science initiative, [The Data Mine](https://datamine.purdue.edu/). 

- **Website:** [https://datamine.purdue.edu](https://datamine.purdue.edu)
- **Source code:** [https://github.com/TheDataMine/datamine](https://github.com/TheDataMine/datamine)
- **Book:** [https://thedatamine.github.io/the-examples-book](https://thedatamine.github.io/the-examples-book)

